pywr.recorders.CSVRecorder — Pywr 0.5dev documentation

# pywr.recorders.CSVRecorder

class `pywr.recorders.` `CSVRecorder`(model, csvfile, scenario_index=0, nodes=None, complib=None, complevel=9, **kwargs)

  A Recorder that saves Node values to a CSV file.

  This class uses the csv package from the Python standard library

  Parameters: | model : pywr.model.Model The model to record nodes from. csvfile : str The path to the CSV file. scenario_index : int The scenario index of the model to save. nodes : iterable (default=None) An iterable of nodes to save data. It defaults to None which is all nodes in the model kwargs : Additional keyword arguments to pass to the csv.writer object

  `__init__`(model, csvfile, scenario_index=0, nodes=None, complib=None, complevel=9, **kwargs)

    Initialize self. See help(type(self)) for accurate signature.

  Methods

  `__init__`(model, csvfile[, scenario_index, …]) | Initialize self.
  `after`() | Write the node values to the CSV file
  `aggregated_value` |
  `before` |
  `finish`() |
  `load`(model, data) |
  `register` |
  `reset`() |
  `setup`() | Setup the CSV file recorder.
  `unregister` |
  `values` |

  Attributes

  `agg_func` |
  `children` |
  `comment` |
  `epsilon` |
  `ignore_nan` |
  `is_constraint` |
  `is_objective` |
  `model` |
  `name` |
  `parents` |